@@ -65,15 +65,12 @@ class Tado:
         # set to None until explicitly set
         self._auto_geofencing_supported = None
 
-    def _create_request(self) -> TadoRequest:
-        return TadoRequest()
-
     def get_me(self):
         """
         Gets home information.
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.action = Action.GET
         request.domain = Domain.ME
 
@@ -84,7 +81,7 @@ class Tado:
         Gets device information.
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "devices"
         return self._http.request(request)
 
@@ -93,7 +90,7 @@ class Tado:
         Gets zones information.
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "zones"
 
         return self._http.request(request)
@@ -110,7 +107,7 @@ class Tado:
         Gets current states of all zones.
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "zoneStates"
 
         return self._http.request(request)
@@ -120,7 +117,7 @@ class Tado:
         Gets current state of Zone.
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone}/state"
         data = {
             **self._http.request(request),
@@ -150,7 +147,7 @@ class Tado:
         # indicates whether presence is current locked (manually set) to
         # HOME or AWAY or not locked (automatically set based on geolocation)
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "state"
         data = self._http.request(request)
 
@@ -186,7 +183,7 @@ class Tado:
         Gets current capabilities of zone.
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/capabilities"
 
         return self._http.request(request)
@@ -207,7 +204,7 @@ class Tado:
         Get the Timetable type currently active
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/schedule/activeTimetable"
         request.mode = Mode.PLAIN
         data = self._http.request(request)
@@ -231,7 +228,7 @@ class Tado:
                 "Incorrect date format, should be YYYY-MM-DD"
             ) from err
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = (
             f"zones/{zone:d}/dayReport?date={day.strftime('%Y-%m-%d')}"
         )
@@ -245,7 +242,7 @@ class Tado:
         id = 3 : SEVEN_DAY (MONDAY, TUESDAY, WEDNESDAY ...)
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/schedule/activeTimetable"
         request.action = Action.CHANGE
         request.payload = {"id": timetable}
@@ -260,7 +257,7 @@ class Tado:
         Get the JSON representation of the schedule for a zone.
         Zone has 3 different schedules, one for each timetable (see setTimetable)
         """
-        request = self._create_request()
+        request = TadoRequest()
         if day:
             request.command = (
                 f"zones/{zone:d}/schedule/timetables/{timetable:d}/blocks/{day}"
@@ -278,7 +275,7 @@ class Tado:
         Set the schedule for a zone, day is required
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = (
             f"zones/{zone:d}/schedule/timetables/{timetable:d}/blocks/{day}"
         )
@@ -293,7 +290,7 @@ class Tado:
         Gets outside weather data
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "weather"
 
         return self._http.request(request)
@@ -303,7 +300,7 @@ class Tado:
         Gets air quality information
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "airComfort"
 
         return self._http.request(request)
@@ -313,7 +310,7 @@ class Tado:
         Gets active users in home
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "users"
 
         return self._http.request(request)
@@ -323,7 +320,7 @@ class Tado:
         Gets information about mobile devices
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "mobileDevices"
 
         return self._http.request(request)
@@ -333,7 +330,7 @@ class Tado:
         Delete current overlay
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/overlay"
         request.action = Action.RESET
         request.mode = Mode.PLAIN
@@ -384,7 +381,7 @@ class Tado:
         if duration is not None:
             post_data["termination"]["durationInSeconds"] = duration
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/overlay"
         request.action = Action.CHANGE
         request.payload = post_data
@@ -396,7 +393,7 @@ class Tado:
         Get current overlay default settings for zone.
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/defaultOverlay"
 
         return self._http.request(request)
@@ -420,7 +417,7 @@ class Tado:
         Sets HomeState to presence
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "presenceLock"
         request.action = Action.CHANGE
         request.payload = {"homePresence": presence}
@@ -434,7 +431,7 @@ class Tado:
 
         # Only attempt to set Auto Geofencing if it is believed to be supported
         if self._auto_geofencing_supported:
-            request = self._create_request()
+            request = TadoRequest()
             request.command = "presenceLock"
             request.action = Action.RESET
 
@@ -469,7 +466,7 @@ class Tado:
         Note: This can only be set if an open window was detected in this zone
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/state/openWindow/activate"
         request.action = Action.SET
         request.mode = Mode.PLAIN
@@ -481,7 +478,7 @@ class Tado:
         Sets the window in zone to closed
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/state/openWindow"
         request.action = Action.RESET
         request.mode = Mode.PLAIN
@@ -494,7 +491,7 @@ class Tado:
         with option to get specific info i.e. cmd='temperatureOffset'
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = cmd
         request.action = Action.GET
         request.domain = Domain.DEVICES
@@ -507,7 +504,7 @@ class Tado:
         Set the Temperature offset on the device.
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "temperatureOffset"
         request.action = Action.CHANGE
         request.domain = Domain.DEVICES
@@ -521,7 +518,7 @@ class Tado:
         Get Energy IQ tariff history
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "tariffs"
         request.action = Action.GET
         request.endpoint = Endpoint.EIQ
@@ -533,7 +530,7 @@ class Tado:
         Get Energy IQ meter readings
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "meterReadings"
         request.action = Action.GET
         request.endpoint = Endpoint.EIQ
@@ -547,7 +544,7 @@ class Tado:
         Send Meter Readings to Tado, date format is YYYY-MM-DD, reading is without decimals
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "meterReadings"
         request.action = Action.SET
         request.endpoint = Endpoint.EIQ
@@ -585,7 +582,7 @@ class Tado:
                 "startDate": from_date,
             }
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "tariffs"
         request.action = Action.SET
         request.endpoint = Endpoint.EIQ
@@ -598,7 +595,7 @@ class Tado:
         Gets available heating circuits
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = "heatingCircuits"
 
         return self._http.request(request)
@@ -608,7 +605,7 @@ class Tado:
         Get zone control information
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/control"
 
         return self._http.request(request)
@@ -618,7 +615,7 @@ class Tado:
         Sets the heating circuit for a zone
         """
 
-        request = self._create_request()
+        request = TadoRequest()
         request.command = f"zones/{zone:d}/control/heatingCircuit"
         request.action = Action.CHANGE
         request.payload = {"circuitNumber": heating_circuit}
